==> deepin-update-ui_1.0.12.tar.xz: BUILD/src/dde-update/translations/dde-update_tr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="tr">
<context>
    <name>CheckProgressWidget</name>
    <message>
        <source>The check is almost complete, thank you for your patience</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Preparing</source>
        <translation>Hazırlanıyor</translation>
    </message>
</context>
<context>
    <name>ErrorFrame</name>
    <message>
        <source>Checked for some errors</source>
        <translation>Bazı hatalar için kontrol edildi</translation>
    </message>
</context>
<context>
    <name>SuccessFrame</name>
    <message>
        <source>Go to Desktop</source>
        <translation>Masaüstüne git</translation>
    </message>
    <message>
        <source>Welcome, system updated successfully</source>
        <translation>Hoş geldiniz, sistem başarıyla güncellendi</translation>
    </message>
    <message>
        <source>Current Edition:</source>
        <translation>Mevcut Yayın:</translation>
    </message>
</context>
<context>
    <name>UpdateCompleteWidget</name>
    <message>
        <source>View Logs</source>
        <translation>Günlükleri görüntüle</translation>
    </message>
    <message>
        <source>Updates successful</source>
        <translation>Güncellemeler başarılı</translation>
    </message>
    <message>
        <source>Your computer will reboot soon %1</source>
        <translation>Bilgisayarınız birazdan yeniden başlatılacak %1</translation>
    </message>
    <message>
        <source>Your computer will be turned off soon %1</source>
        <translation>Bilgisayarınız birazdan kapatılacak %1</translation>
    </message>
    <message>
        <source>The automatic reboot process has failed. Please try to manually reboot your device.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The automatic shutdown process has failed. Please try to manually shut down your device.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UpdateLogWidget</name>
    <message>
        <source>Hide Logs</source>
        <translation>Günlükleri gizle</translation>
    </message>
</context>
<context>
    <name>UpdateModel</name>
    <message>
        <source>Update failed</source>
        <translation>Güncelleme başarısız oldu</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Bilinmeyen hata</translation>
    </message>
    <message>
        <source>Backup failed</source>
        <translation>Yedekleme başarısız oldu</translation>
    </message>
    <message>
        <source>Unable to perform system backup. If you continue the updates, you cannot roll back to the old system later.</source>
        <translation>Sistem yedeklemesi gerçekleştirilemiyor. Güncellemelere devam ederseniz, daha sonra eski sisteme geri dönemezsiniz.</translation>
    </message>
    <message>
        <source>Insufficient disk space. Please clean up your disk and try again.</source>
        <translation>Yetersiz disk alanı. Lütfen diskinizi temizleyin ve tekrar deneyin.</translation>
    </message>
    <message>
        <source>Failed to connect to backup services. Please check and retry again.</source>
        <translation>Yedekleme hizmetlerine bağlanılamadı. Lütfen kontrol edin ve tekrar deneyin.</translation>
    </message>
    <message>
        <source>Failed to connect to update services. Please check and retry again.</source>
        <translation>Güncelleştirme hizmetlerine bağlanılamadı. Lütfen kontrol edin ve tekrar deneyin.</translation>
    </message>
    <message>
        <source>Dependency error</source>
        <translation>Bağımlılık hatası</translation>
    </message>
    <message>
        <source>DPKG error</source>
        <translation>DPKG hatası</translation>
    </message>
    <message>
        <source>Back Up Again</source>
        <translation>Tekrar Yedekle</translation>
    </message>
    <message>
        <source>Abort</source>
        <translation>İptal et</translation>
    </message>
    <message>
        <source>Proceed to Update</source>
        <translation>Güncellemeye devam et</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Yeniden başlat</translation>
    </message>
    <message>
        <source>Shut Down</source>
        <translation>Kapat</translation>
    </message>
    <message>
        <source>Go to Desktop</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UpdatePrepareWidget</name>
    <message>
        <source>Preparing for updates…</source>
        <translation>Güncellemeler için hazırlanıyor...</translation>
    </message>
</context>
<context>
    <name>UpdateProgressWidget</name>
    <message>
        <source>Do not force a shutdown or power off when installing updates. Otherwise, your system may be damaged.</source>
        <translation>Güncellemeleri yüklerken bilgisayarı kapatmaya veya gücü kapatmaya zorlamayın. Aksi takdirde sisteminiz zarar görebilir.</translation>
    </message>
</context>
</TS>

==> deepin-update-ui_1.0.21.tar.xz: BUILD/src/dde-update/translations/dde-update_tr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="tr">
<context>
    <name>CheckProgressWidget</name>
    <message>
        <source>The check is almost complete, thank you for your patience</source>
        <translation>Kontrol neredeyse tamamlandı, sabrınız için teşekkür ederiz</translation>
    </message>
    <message>
        <source>Preparing</source>
        <translation>Hazırlanıyor</translation>
    </message>
</context>
<context>
    <name>ErrorFrame</name>
    <message>
        <source>Checked for some errors</source>
        <translation>Bazı hatalar için kontrol edildi</translation>
    </message>
</context>
<context>
    <name>SuccessFrame</name>
    <message>
        <source>Go to Desktop</source>
        <translation>Masaüstüne git</translation>
    </message>
    <message>
        <source>Welcome, system updated successfully</source>
        <translation>Hoş geldiniz, sistem başarıyla güncellendi</translation>
    </message>
    <message>
        <source>Current Edition:</source>
        <translation>Mevcut Yayın:</translation>
    </message>
</context>
<context>
    <name>UpdateCompleteWidget</name>
    <message>
        <source>Updates successful</source>
        <translation>Güncellemeler başarılı</translation>
    </message>
    <message>
        <source>Your computer will reboot soon %1</source>
        <translation>Bilgisayarınız birazdan yeniden başlatılacak %1</translation>
    </message>
    <message>
        <source>Your computer will be turned off soon %1</source>
        <translation>Bilgisayarınız birazdan kapatılacak %1</translation>
    </message>
    <message>
        <source>The automatic reboot process has failed. Please try to manually reboot your device.</source>
        <translation>Otomatik yeniden başlatma işlemi başarısız oldu. Lütfen cihazınızı manuel olarak yeniden başlatmayı deneyin.</translation>
    </message>
    <message>
        <source>The automatic shutdown process has failed. Please try to manually shut down your device.</source>
        <translation>Otomatik kapatma işlemi başarısız oldu. Lütfen cihazınızı manuel olarak kapatmayı deneyin.</translation>
    </message>
    <message>
        <source>View update logs</source>
        <translation>Güncelleme günlüklerini görüntüle</translation>
    </message>
    <message>
        <source>Collapse update logs</source>
        <translation>Güncelleme günlüklerini daralt</translation>
    </message>
</context>
<context>
    <name>UpdateLogWidget</name>
    <message>
        <source>Export</source>
        <translation>Dışarı aktar</translation>
    </message>
    <message>
        <source>The log has been exported to the desktop</source>
        <translation>Günlük masaüstüne aktarıldı</translation>
    </message>
    <message>
        <source>Log export failed, please try again</source>
        <translation>Günlük aktarımı başarısız oldu, lütfen tekrar deneyin</translation>
    </message>
</context>
<context>
    <name>UpdateModel</name>
    <message>
        <source>Update failed</source>
        <translation>Güncelleme başarısız oldu</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Bilinmeyen hata</translation>
    </message>
    <message>
        <source>Backup failed</source>
        <translation>Yedekleme başarısız oldu</translation>
    </message>
    <message>
        <source>Unable to perform system backup. If you continue the updates, you cannot roll back to the old system later.</source>
        <translation>Sistem yedeklemesi gerçekleştirilemiyor. Güncellemelere devam ederseniz, daha sonra eski sisteme geri dönemezsiniz.</translation>
    </message>
    <message>
        <source>Insufficient disk space. Please clean up your disk and try again.</source>
        <translation>Yetersiz disk alanı. Lütfen diskinizi temizleyin ve tekrar deneyin.</translation>
    </message>
    <message>
        <source>Failed to connect to backup services. Please check and retry again.</source>
        <translation>Yedekleme hizmetlerine bağlanılamadı. Lütfen kontrol edin ve tekrar deneyin.</translation>
    </message>
    <message>
        <source>Failed to connect to update services. Please check and retry again.</source>
        <translation>Güncelleştirme hizmetlerine bağlanılamadı. Lütfen kontrol edin ve tekrar deneyin.</translation>
    </message>
    <message>
        <source>Dependency error</source>
        <translation>Bağımlılık hatası</translation>
    </message>
    <message>
        <source>DPKG error</source>
        <translation>DPKG hatası</translation>
    </message>
    <message>
        <source>Back Up Again</source>
        <translation>Tekrar Yedekle</translation>
    </message>
    <message>
        <source>Abort</source>
        <translation>İptal et</translation>
    </message>
    <message>
        <source>Proceed to Update</source>
        <translation>Güncellemeye devam et</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Yeniden başlat</translation>
    </message>
    <message>
        <source>Shut Down</source>
        <translation>Kapat</translation>
    </message>
    <message>
        <source>Go to Desktop</source>
        <translation>Masaüstüne git</translation>
    </message>
</context>
<context>
    <name>UpdatePrepareWidget</name>
    <message>
        <source>Preparing for updates…</source>
        <translation>Güncellemeler için hazırlanıyor...</translation>
    </message>
</context>
<context>
    <name>UpdateProgressWidget</name>
    <message>
        <source>Do not force a shutdown or power off when installing updates. Otherwise, your system may be damaged.</source>
        <translation>Güncellemeleri yüklerken bilgisayarı kapatmaya veya gücü kapatmaya zorlamayın. Aksi takdirde sisteminiz zarar görebilir.</translation>
    </message>
    <message>
        <source>View update logs</source>
        <translation>Güncelleme günlüklerini görüntüle</translation>
    </message>
    <message>
        <source>Collapse update logs</source>
        <translation>Güncelleme günlüklerini daralt</translation>
    </message>
</context>
<context>
    <name>UpdateWorker</name>
    <message>
        <source>updatelog</source>
        <translation>güncelleme günlüğü</translation>
    </message>
</context>
</TS>
